@@ -131,6 +131,9 @@ typedef struct {
 	int g_do_show_linesM; /* used by swverify */
 	char * g_catalog_info_nameM; /* used by swverify */
 	char * g_system_info_nameM; /* used by swverify */
+	int g_justdbM; /* operate on installed catalog only */
+	int g_do_dereferenceM;
+	int g_ignore_slack_installM;
 } GB;
 
 #define G_opta (G->optaM)
