@@ -9,7 +9,7 @@
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,34 +17,58 @@
  GNU General Public License for more details.
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
-
-
 #include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
-#include "swinfo.h"
-#include "swindex.h"
-#include "swinstalled.h"
-#include "swpsf.h"
-#include "swoption.h"
+#include <errno.h>
+#include <unistd.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <limits.h>
+#include <string>
+#include <typeinfo>
+#include "stream_config.h"
 
 extern "C" {
+#include "swparse.h"
 #include "usgetopt.h"
 #include "ugetopt_help.h"
-#include "swparser_global.h"
-#include "swparse.h"
-#include "swcommon_options.h"
-#include "swevents_array.h"
+#include "swlib.h"
+#include "swfork.h"
+#include "swevents.h"
+#include "swheader.h"
+#include "swheaderline.h"
+#include "swcommon.h"
+#include "swgp.h"
+#include "fmgetpass.h"
 #include "swutilname.h"
+#include "swfdio.h"
+#include "swextopt.h"
 }
 
+#include "swmain.h"  /* this file should be included by the main program file */
+#include "swparser.h"
+#include "swdefinitionfile.h"
+#include "swpsf.h"
+#include "swpackagefile.h"
+#include "swexstruct.h"
+#include "swexdistribution.h"
+
+#include "swexfileset.h"
+#include "swexproduct.h"
+#include "swexpsf.h"
+#include "swexdistribution.h"
+#include "swscollection.h"
+#include "swinstalled.h"
+#include "swinfo.h"
+#include "swoption.h"
+
 extern int swparse_atlevel;
 extern char  swlex_filename[512];
 
-
 static int usage (char * progname, struct option  lop[])
 {
     fprintf (stderr, "A POSIX-7.2 Metadata parser and testing and development.\n");
@@ -86,7 +110,7 @@ int main (int argc, char *argv[])
 {
   int fd, c=0, ret;
   char  *progname;
-  swDefinitionFile * swdef=NULL;
+  swDefinitionFile * swdef = NULL;
   int oForm = SWPARSE_FORM_MKUP;
   int do_debug = 0;
  
