@@ -1,6 +1,6 @@
 /*  swinstall_lib.c -- the top-level routines of swinstall
 
- Copyright (C) 2004,2005,2006,2007 Jim Lowe
+ Copyright (C) 2004,2005,2006,2007,2008 Jim Lowe
  All Rights Reserved.
   
  COPYING TERMS AND CONDITIONS:
@@ -959,6 +959,64 @@ construct_execution_phase_script(GB * G, SWI * swi,
 
 	return 0;
 }
+	
+static
+void
+construct_directory_ownership_script(SWI * swi, STROB * dir_owner_buf, char * isc_path)
+{
+	mode_t mode;
+	STROB * tmp;
+	STROB * tmp2;
+	STROB * path2;
+	char * s;
+
+	tmp = strob_open(32);
+	tmp2 = strob_open(32);
+	path2 = strob_open(32);
+
+	/* set a failsafe value */
+	strob_strcpy(dir_owner_buf, "true");
+	
+	strob_strcpy(tmp, swi->swi_pkgM->catalog_entryM);
+	swlib_squash_leading_slash(strob_str(tmp));
+
+	s = strstr(strob_str(tmp), isc_path);
+	if (s != strob_str(tmp)) {
+		/* error */
+		return;
+	}
+	s += (strlen(isc_path));
+	swlib_squash_leading_slash(isc_path);
+	swlib_squash_leading_slash(s);
+
+        mode = swi->swi_pkgM->installed_catalog_modeM;
+	strob_strcpy(tmp, "");
+	s = strob_strtok(tmp2, s, "/");
+	while(s) {
+		if (swi->swi_pkgM->installed_catalog_ownerM == NULL) return;
+		if (swi->swi_pkgM->installed_catalog_groupM == NULL) return;
+		if (strlen(swi->swi_pkgM->installed_catalog_ownerM) == 0) return;
+		if (strlen(swi->swi_pkgM->installed_catalog_groupM) == 0) return;
+		swlib_unix_dircat(path2, s);
+		strob_sprintf(tmp, 1, "chown '%s':'%s' '%s/%s'\n",
+			swi->swi_pkgM->installed_catalog_ownerM,
+			swi->swi_pkgM->installed_catalog_groupM,
+			isc_path,
+			strob_str(path2));
+		if (mode & S_ISVTX) {
+			strob_sprintf(tmp, 1, "chmod o+t '%s/%s'\n",
+				isc_path,
+				strob_str(path2));
+		}
+		s = strob_strtok(tmp2, NULL, "/");
+	}	
+	if (strob_strlen(tmp) > 10)  /* silly sanity check */
+		strob_strcpy(dir_owner_buf, strob_str(tmp));
+	strob_close(path2);
+	strob_close(tmp2);
+	strob_close(tmp);
+	return;
+}
 
 int
 run_analysis_script(GB * G, SWI * swi, int ofd, int event_fd, int * p_checkinstall_status)
@@ -1138,6 +1196,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	STROB * current_path_expanded;
 	STROB * relocated_current_path;
 	STROB * shell_lib_buf;
+	STROB * dir_owner_buf;
 	AHS * info_ahs2 = ahs_open();
 	char * obj;
 	int tarheaderflags;
@@ -1183,6 +1242,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	catalogdir = strob_open(100);
 	newnamebuf = strob_open(100);
 	tmp_swpath_ex = strob_open(100);
+	dir_owner_buf = strob_open(100);
 	namebuf = strob_open(100);
 	tmp = strob_open(10);
 	current_path_expanded = strob_open(10);
@@ -1318,15 +1378,24 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		modemask = 02;
 	}
 
+	construct_directory_ownership_script(swi, dir_owner_buf,
+			get_opta(G->optaM, SW_E_installed_software_catalog));
+
+	E_DEBUG2("swi->swi_pkgM->catalog_entryM=[%s]", swi->swi_pkgM->catalog_entryM);
 	if (opt_preview == 0 && retval == 0 && G->g_to_stdout == 0) {
 		swicol_set_task_idstring(swi->swicolM, SWBIS_TS_make_catalog_dir);
 		strob_sprintf(tmp, 0,
 			"(umask %o; mkdir -p \"%s\")</dev/null\n"
 			"sw_retval=$?\n"
+			"(\n"
+			"%s\n"
+			")</dev/null\n"
 			"dd count=1 bs=512 of=/dev/null 2>/dev/null\n"
 			,
 			(unsigned int)modemask,
-			swi->swi_pkgM->catalog_entryM);
+			swi->swi_pkgM->catalog_entryM,
+			strob_str(dir_owner_buf)
+			);
 
 		ret = swicol_rpsh_task_send_script2(
 			swi->swicolM,
@@ -1500,7 +1569,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			did_sigfiles == 0 &&
 			package_is_signed > 0 &&
 			is_catalog == SWPATH_CTYPE_CAT &&
-			strstr(swpath_get_pathname(swpath), "signature")
+			strstr(swpath_get_pathname(swpath), SW_A_signature)
 		) {
 			/*
 			 * Write out all the signatures.
@@ -2468,6 +2537,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	strob_close(tmp);
 	strob_close(current_path_expanded);
 	strob_close(tmp_swpath_ex);
+	strob_close(dir_owner_buf);
 	strob_close(resolved_path);
 	strob_close(execution_phase_script);
 	taru_free_header(file_hdr);
