@@ -197,14 +197,7 @@ class swExStruct_i: public swExStruct
 	virtual int containedListAdd(swExStruct * o) {
 		assert(0); return 0;
 	}
-/*
-	virtual int write (){
-			if (mediaTypeM)
-				return write_serial();
-			else
-				return write_directory();
-	}
-*/
+	
 	virtual swPtrList<swPackageFile> * getFileListObject(void) {
 		return NULL;
 	}
@@ -373,7 +366,7 @@ class swExStruct_i: public swExStruct
 	}
 	
 	char * getSourcePath(swDefinition * swdef) {
-		return swdef->find("source");
+		return swdef->find(SW_A_source);
 	}
 
 	void doInitializeParentsPaths(char * formed_path) { ; }
@@ -655,7 +648,7 @@ class swExStruct_i: public swExStruct
 			att = inext->get_next_node();  // The first attribute.
 			while (att) {
 				if (::strcmp(att->get_keyword(),
-							"source") == 0) {
+							SW_A_source) == 0) {
 					att->vremove();
 				}
 				att = att->get_next_node();
@@ -719,16 +712,6 @@ class swExStruct_i: public swExStruct
 			"xxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
 		);
 	}
-	
-	//static void 
-	//registerEmitMethod(swDefinitionFile * swp) {
-	//	swExStruct_i::emitFileM = swp;
-	//}
-	
-	//static int 
-	//runEmitMethod(int fd) {
-	//	return swExStruct_i::emitFileM->swdeffile_linki_write_fd(fd);
-	//}
 
 	static int 
 	swexstruct_write_definitionfile(swDefinitionFile * swfile, time_t ptm,
