@@ -1579,8 +1579,8 @@ class swObjFiles_i:  public swExStruct_i
 		char * name;
 		char *s;
         	char * base = (char*)NULL;
-		const char * signame = "signature";
-		const char * sigpath = "/signature";
+		const char * signame = SW_A_signature;
+		const char * sigpath = "/" SW_A_signature;
 		
 		old_fd = get_ofd();	
 		old_preview_fd = get_preview_fd();	
