@@ -20,7 +20,13 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
+#define FILENEEDDEBUG 1
+#undef FILENEEDDEBUG
+
+extern "C" {
 #include "swuser_config.h"
+}
+
 #include <stdio.h>
 #include <string.h>
 #include "swdefinition.h"
@@ -43,23 +49,38 @@ extern "C" {
 
 swDefinition * swDefinition::swdefinition_factory (char * parserline) {
 
-	    int i;
-	    swDefinition * swdef = NULL;
-	    char * object_keyword = swheaderline_get_keyword(parserline); 
+    int i;
+    swDefinition * swdef = NULL;
+    char * object_keyword = swheaderline_get_keyword(parserline); 
 	     
-	     if ( !::strcmp ("file",object_keyword )) { swdef = swDefFile::make_definition(); }
-        else if ( !::strcmp ("control_file",object_keyword )) { swdef = swDefControlFile::make_definition(); }
-        else if ( !::strcmp ("category",object_keyword )) { swdef = swDefCategory::make_definition(); }
-        else if ( !::strcmp ("fileset",object_keyword )) { swdef = swDefFileset::make_definition(); }
-        else if ( !::strcmp ("product",object_keyword )) { swdef = swDefProduct::make_definition(); }
-        else if ( !::strcmp ("subproduct",object_keyword )) { swdef = swDefsubProduct::make_definition(); }
-        else if ( !::strcmp ("distribution",object_keyword )) { swdef = swDefDistribution::make_definition(); }
-        else if ( !::strcmp ("media",object_keyword )) { swdef = swDefMedia::make_definition(); }
-        else if ( !::strcmp ("bundle",object_keyword )) { swdef = swDefBundle::make_definition(); }
-        else if ( !::strcmp ("host",object_keyword )) { swdef = swDefHost::make_definition(); }
-        else if ( !::strcmp ("installed_software",object_keyword )) { swdef = swDefInstalled_Software::make_definition(); }
-        else if ( !::strcmp ("vendor",object_keyword )) { swdef = swDefVendor::make_definition(); }
-        else { return static_cast<swDefinition *>(NULL); }
+	if ( !::strcmp (SW_A_file, object_keyword )) {
+		E_DEBUG2("making file \n\n[%s]\n\n", parserline);
+		swdef = swDefFile::make_definition(); 
+	} else if ( !::strcmp (SW_A_control_file, object_keyword )) {
+		swdef = swDefControlFile::make_definition();
+	} else if ( !::strcmp (SW_A_category, object_keyword )) {
+		swdef = swDefCategory::make_definition();
+	} else if ( !::strcmp (SW_A_fileset, object_keyword )) {
+		swdef = swDefFileset::make_definition();
+	} else if ( !::strcmp (SW_A_product, object_keyword )) {
+		swdef = swDefProduct::make_definition();
+	} else if ( !::strcmp (SW_A_subproduct, object_keyword )) {
+		swdef = swDefsubProduct::make_definition();
+	} else if ( !::strcmp (SW_A_distribution, object_keyword )) {
+		swdef = swDefDistribution::make_definition();
+	} else if ( !::strcmp (SW_A_media, object_keyword )) {
+		swdef = swDefMedia::make_definition();
+	} else if ( !::strcmp (SW_A_bundle, object_keyword )) {
+		swdef = swDefBundle::make_definition();
+	} else if ( !::strcmp (SW_A_host, object_keyword )) {
+		swdef = swDefHost::make_definition();
+	} else if ( !::strcmp (SW_A_installed_software, object_keyword )) {
+		swdef = swDefInstalled_Software::make_definition();
+	} else if ( !::strcmp (SW_A_vendor, object_keyword )) {
+		swdef = swDefVendor::make_definition();
+	} else {
+		return static_cast<swDefinition *>(NULL);
+	}
 
 	assert(swdef);
 	swdef->set_p_offset((i=parserline - static_cast<char*>(swdef->get_mem_addr()),i));
@@ -155,12 +176,32 @@ int swDefinition::list_add_if_new(swMetaData * swmd)
 	return 0;
 }
 
+void swDefinition::list_replace_if_not_explicitly_set(swMetaData * swmd)
+{
+	swMetaData *p;
+	char * keyword;
+
+	keyword = swmd->get_keyword();
+	p = findAttribute(keyword);
+	if (!p) {
+		list_add(swmd);
+	} else {
+		if (p->get_is_explicit() == 0) {
+			list_replace(swmd);
+		} else {
+			/* do nothing */
+			;
+		}
+	}
+}
+
+
 void swDefinition::list_replace(swMetaData * swmd)
 {
 	char * keyword = swmd->get_keyword();
 	if (find(keyword) != static_cast<char*>(NULL)) {
 		// Delete all attributes of this keyword.
-		while(deleteAttribute(keyword) != static_cast<char *>(NULL));
+		while(deleteAttribute(keyword) != static_cast<char *>(NULL)) { ; }
 	}
 	list_add(swmd);
 }
@@ -214,7 +255,6 @@ int swDefinition::write_fd_debug(int uxfio_fd, char * prefix) {
 	return ret;
 }
 
-
 char * swDefinition::deleteAttribute(char * keyword)
 { 
 	swMetaData *oldp = this;
@@ -224,7 +264,9 @@ char * swDefinition::deleteAttribute(char * keyword)
 	char * value = static_cast<char*>(NULL);
 
 	while (p){
-		if (!::strcmp(keyword, p->get_keyword())){
+		if (
+			::strcmp(keyword, p->get_keyword()) == 0
+		 ) {
 			value = p->get_value((int*)NULL);
 			p->set_contained_by(NULL);
 			next = p->get_next_node();
@@ -279,7 +321,7 @@ char * swDefinition::find(char * keyword)
 
 char * swDefinition::getPathAttribute(void)
 {
-	return find("path");
+	return find(SW_A_path);
 }
 
 char * swDefinition::getTagAttribute(void)
@@ -354,7 +396,7 @@ swMetaData * swDefinition::get_attribute_by_index(int n)
 	int i=0;
 	swMetaData *p=this;
 	if (!n) return this;
-	while (((p=p->get_next_node()) != NULL) && i++ <  n);
+	while (((p=p->get_next_node()) != NULL) && i++ <  n) { ; }
 	return p;
 }
 
@@ -394,7 +436,7 @@ swDefinition * swDefinition::make_newDefinition (swDefinition * parent_swdef, ch
 }
 
 void
-swDefinition::merge(swDefinition * source, int do_unconditionally)
+swDefinition::merge(swDefinition * source, int do_all, int do_replace)
 {
 	//
 	// Merge <this> with attributes of <source>.
@@ -412,7 +454,7 @@ swDefinition::merge(swDefinition * source, int do_unconditionally)
 	p = source->get_next_node();
 	while (p) {
 		keyword = p->get_keyword();
-		if (p->get_is_explicit() || do_unconditionally) {
+		if (p->get_is_explicit() || do_all) {
 			if (*keyword == '_') {
 				//
 				// keywords that begin with '_' are internal.
@@ -429,9 +471,13 @@ swDefinition::merge(swDefinition * source, int do_unconditionally)
 				//
 				// fprintf(stderr, "JL replacing %s with value %s\n",
 				// 	keyword, p->get_value((int*)(NULL)));
-				vremove(keyword);
-				SWDEFINITION_DEBUG3("replacing : attribute=[%s]   new value is [%s]", keyword, p->get_value((int*)(NULL)));
-				add(keyword, p->get_value((int*)(NULL)), status);
+				if (do_replace) {
+					vremove(keyword);
+					add(keyword, p->get_value((int*)(NULL)), status);
+					if (strcmp(keyword, SW_A_source) == 0) {
+						vremove(keyword);
+					}
+				}
 			} else {
 				//
 				// Add it.
@@ -459,13 +505,13 @@ void swDefinition::set_tag_attribute(void) { }
 void 
 swDefinition::set_path_attribute(char * source)
 {
-	char * path = find("path");
+	char * path = find(SW_A_path);
 	if (path) return;
 
 	//
 	// Section 5.2.11 Lines 677-678
 	//
-	add("path", source);
+	add(SW_A_path, source);
 }
 
 
