@@ -96,11 +96,11 @@ int swPackageFile::initialize_file_stats_array(swDefinition * swdef,
 				swmd = swdef->findAttribute(namesM[i]);
 				if (swmd) {
 					value = swmd->get_value((int*)(NULL));
-					SWPACKAGEFILE_DEBUG3("setting attribute [%s] == [%s]", namesM[i], value);
+					SWPACKAGEFILE_DEBUG3("INIT: setting attribute [%s] == [%s]", namesM[i], value);
 					::swlib_strncpy(fileArray[i], value, file_permsLength);
 					fileArrayWasSet[i] = 1;
 				} else {
-					SWPACKAGEFILE_DEBUG3("NOT setting attribute [%s] == [%s]", namesM[i], value);
+					SWPACKAGEFILE_DEBUG2("INIT: NOT setting attribute [%s]", namesM[i]);
 					;
 				}
 				break;
@@ -131,13 +131,16 @@ swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, char *s
 	struct stat st;
 	char fileArray			[lastE+1][file_permsLength];
 	int  fileArrayWasSet		[lastE+1];
-	swMetaData * swmd;	
+	swMetaData * swmd;
+	swMetaData * swmd2;
 	SWVARFS * swvarfs1 = (SWVARFS*)xFormat_get_swvarfs();
 	int level = swdef->get_level();
 	char * umask_value;
+	char * value;
 	int i;
 
-	SWPACKAGEFILE_DEBUG("");
+	SWPACKAGEFILE_DEBUG("ENTERING");
+	SWPACKAGEFILE_DEBUG2("source=[%s]", source);
 	if (source == NULL) {
 		//
 		// Determine what to use as the effective source from the contents
@@ -151,13 +154,17 @@ swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, char *s
 
 	SWLIB_ASSERT(swvarfs == swvarfs1);
 
-	//if (*source == SWBIS_NO_STAT_INDICATOR_C) return 0;
-	if (swdef->get_no_stat()) return 0;
+	if (	swdef->get_no_stat() ||
+		swdef->get_storage_status() == SWDEF_STATUS_DUP ||
+		0
+	) {
+		//
+		// don't set the implicit file stats
+		//
+		SWPACKAGEFILE_DEBUG3("returning get_no_stat=[%d] storage_status=[%d]", swdef->get_no_stat(), swdef->get_storage_status());
+ 		return 0;
+	}
 
-	//for (i=0; i<=lastE; i++) {
-	//	*fileArray[i]='\0';
-	//	fileArrayWasSet[i] = 0;
-	//}
 	initialize_file_stats_array(swdef, fileArray, fileArrayWasSet);
 
 	swmd = swdef->findAttribute("umask");
@@ -178,8 +185,8 @@ swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, char *s
 	
 	cksumflags = swdef->apply_cksum_policy_specialization(cksumflags);  // cksum are on for control_files.
 
+	SWPACKAGEFILE_DEBUG2("running stat on [%s]", source);
 	if (xFormat_u_lstat(source, &st) != 0) {
-		// fprintf(stderr, "_u_lstat error : %s\n", source);
 		return -9991;
 	}
 
@@ -209,12 +216,14 @@ swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, char *s
 				case sizeE:
 				case typeE:
 				case linksourceE:
+					swdef->list_replace_if_not_explicitly_set(swmd);
+					break;
 				case volaE:
 				case compE:
 				case cksumE:
 				case md5sumE:
 				case sha1sumE:
-					SWPACKAGEFILE_DEBUG("");
+					SWPACKAGEFILE_DEBUG3("setting %s to value [%s]", namesM[i], swmd->get_value(NULL));
 					swdef->list_replace(swmd);
 					break;
 				case ownerE:
@@ -224,7 +233,23 @@ swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, char *s
 					break;
 				case majorE:
 				case minorE:
-					SWPACKAGEFILE_DEBUG("");
+					SWPACKAGEFILE_DEBUG2("storage status is %d", swdef->get_storage_status());
+					SWPACKAGEFILE_DEBUG("setting minor/major");
+					/***********************
+					swmd2 = swdef->findAttribute(SW_A_type);
+					if (swmd2) {
+						value = swmd2->get_value(NULL);
+						if (value &&
+							(
+							strcmp(value, "c") == 0 ||
+							strcmp(value, "b") == 0
+							)
+						) {
+							SWPACKAGEFILE_DEBUG("NOT setting minor/major because of type");
+							break;
+						}
+					}
+					******************/
 					if (
 						*fileArray[typeE] == 'c' ||
 						*fileArray[typeE] == 'b'
