@@ -21,13 +21,21 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
+
+extern "C" {
+#define FILENEEDDEBUG 1
+#undef FILENEEDDEBUG
 #include "swuser_config.h"
+}
+
 #include "swpsf.h"
 
 swDefinition * swPSF::makeDefinition (char * parser_line, int * retval) {
 	swDefinition * swdef;
 	swMetaData * attributes;
 	char * keyword = swheaderline_get_keyword(parser_line);
+
+	E_DEBUG("");
 	
 	//
 	// Sanity Check.
@@ -43,9 +51,9 @@ swDefinition * swPSF::makeDefinition (char * parser_line, int * retval) {
 	// don't influence the next fileset or product object.
 	//
 	if (
-		!::strcmp(keyword, "product") || 
-		!::strcmp(keyword, "fileset") ||
-		!::strcmp(keyword, "bundle") ||
+		!::strcmp(keyword, SW_A_product) || 
+		!::strcmp(keyword, SW_A_fileset) ||
+		!::strcmp(keyword, SW_A_bundle) ||
 		0
 	) {
 		swextM->reset();		
@@ -67,9 +75,9 @@ swDefinition * swPSF::makeDefinition (char * parser_line, int * retval) {
 	// Only filesets and products contain extended definitions.
 	//
 	if (
-		!::strcmp(keyword, "product") || 
-		!::strcmp(keyword, "fileset") ||
-		!::strcmp(keyword, "bundle") ||
+		!::strcmp(keyword, SW_A_product) || 
+		!::strcmp(keyword, SW_A_fileset) ||
+		!::strcmp(keyword, SW_A_bundle) ||
 		0
 	) {
 		swdefM = static_cast<swDefinition*>(swdef);
@@ -81,7 +89,7 @@ swDefinition * swPSF::makeDefinition (char * parser_line, int * retval) {
 	// same <path> attribute value.
 	//
 	if (
-		!::strcmp(keyword, "fileset") ||
+		!::strcmp(keyword, SW_A_fileset) ||
 		0
 	) {
 		swextM->set_fileset_start_index(this);
@@ -90,7 +98,7 @@ swDefinition * swPSF::makeDefinition (char * parser_line, int * retval) {
 	attributes = swdef->generate_attribute_list(swdef->get_level()  + 1  , retval); 
 	swdef->set_next_node(attributes);
 	
-	if (!::strcmp(keyword, "file") || !::strcmp(keyword, "control_file")) {
+	if (!::strcmp(keyword, SW_A_file) || !::strcmp(keyword, SW_A_control_file)) {
 		if (swextM->filePermissionsActive()) {
 			//
 			// Set the default filePermissions.
@@ -115,6 +123,7 @@ swMetaData * swPSF::generate_attribute_list(int at_level, int *retvalp) {
 	// first line in the while loop (below), otherwise terminate the loop.
 	//
 
+	E_DEBUG("");
 	set_next_node(NULL);
 	p = (char*)get_mem_addr();
 	prevnode=this;
@@ -126,6 +135,7 @@ swMetaData * swPSF::generate_attribute_list(int at_level, int *retvalp) {
 		parser_line = p + offset;
 		u_type=swMetaData::determine_type(parser_line);
 		oldoff=uxfio_lseek(get_mem_fd(), 0, SEEK_CUR);
+		E_DEBUG2("%s", parser_line);
 		switch(u_type) {	
 			case swstructdef::sdf_attribute_kw:
 				if (swheaderline_get_keyword(parser_line)) {
@@ -137,6 +147,7 @@ swMetaData * swPSF::generate_attribute_list(int at_level, int *retvalp) {
 					node = new swAttribute(parser_line, at_level);
 					node->set_p_offset(offset); 
 					node->set_ino(offset); 
+					node->set_is_explicit(); 
 
 					//
 					// seek back (i.e forward) to the old position.
@@ -144,6 +155,7 @@ swMetaData * swPSF::generate_attribute_list(int at_level, int *retvalp) {
 					uxfio_lseek(get_mem_fd(), oldoff, SEEK_SET);
 					swFileMapSetCurrentOffset(oldoff);				
 					if (!head) head=node; 
+					E_DEBUG("attribute");
 					if (!get_next_node()) {
 						set_next_node(node);
 						node->set_next_node(static_cast<swMetaData*>(NULL));
@@ -159,6 +171,7 @@ swMetaData * swPSF::generate_attribute_list(int at_level, int *retvalp) {
 				break;
 			case swstructdef::sdf_extended_kw:
 				if(!nloops) {
+					E_DEBUG2("running processExtendedDefinition on %s", parser_line);
 					if (swextM->processExtendedDefinition(parser_line, this, swdefM)) {
 						u_break=1;
 						retval--;
@@ -170,6 +183,7 @@ swMetaData * swPSF::generate_attribute_list(int at_level, int *retvalp) {
 					// This line must be read again, therefore seek back
 					// to it.
 					//
+					E_DEBUG("terminate attribute processing");
 					uxfio_lseek(get_mem_fd(), offset, SEEK_SET);
 				}
 				swFileMapSetCurrentOffset(oldoff);				
