@@ -52,7 +52,7 @@ public:
 		char * tag = swdef->find(SW_A_tag);
 		if (!tag) {
 			char *r;
-			char * path = swdef->find("path");
+			char * path = swdef->find(SW_A_path);
 			if (!path) {
 				return static_cast<char*>(NULL);
 			}
