@@ -145,6 +145,22 @@ ls_list_set_encoding_by_lang(void)
 	return flag;
 }
 
+static
+char *
+prepend_dotslash(char *str, STROB * fp)
+{
+    if (strcmp(str, ".") == 0) {
+       return "./";
+    } else if (strncmp(str, "./", 2) == 0) {
+       return str;
+    } else if (strcmp(str, "/") == 0) {
+       strob_strcat(fp, ".");
+    } else {
+       strob_strcat(fp, "./");
+    }
+    return str;
+}
+
 static
 char *
 tartime(time_t t)
@@ -175,7 +191,7 @@ strip_slash(char * pname, int vflag)
 	char * name;
 	name = pname;
 	if (vflag & LS_LIST_VERBOSE_STRIPSLASH) {
-		while( name && *name == '.' && *(name+1) == '/') name++;
+		while( name && *name == '.' && *(name+1) == '/' /*&& *(name+2) != '\0'*/) name++;
 		while( name && *name == '/' && *(name+1) != '\0' ) name++;
 	}
 	return name;
@@ -225,10 +241,17 @@ safe_print (char *str, FILE * fp)
 }
 
 void
-ls_list_safe_print_to_strob(char *str, STROB * fp)
+ls_list_safe_print_to_strob(char *fp_str, STROB * fp, int do_prepend)
 {
   char visbuf[5];
   char *cp;
+  char * str;
+
+  if (do_prepend) {
+	str = prepend_dotslash(fp_str, fp);
+  } else {
+	str = fp_str;
+  }
 
   if (1 || /* isatty (fileno (fp))*/ 0 )
     {
@@ -362,11 +385,11 @@ print_linkname(STROB * fp, int type, char * ln_name)
 	if ((type == PAX_HLK) || (type == PAX_HRG)) {
 		/* strob_strcat(fp, " == "); */
 		strob_strcat(fp, " link to ");
-		ls_list_safe_print_to_strob(ln_name, fp);
+		ls_list_safe_print_to_strob(ln_name, fp, 0);
 	} else {
 		if (type == PAX_SLK) {
 			strob_strcat(fp, " -> ");
-			ls_list_safe_print_to_strob(ln_name, fp);
+			ls_list_safe_print_to_strob(ln_name, fp, 0);
     		}
 	}
 }
@@ -427,7 +450,7 @@ alt_ls_list_to_string(char * fp_name, char * ln_name, struct new_cpio_header * f
 
 	mtime = (time_t)(file_hdr->c_mtime);
 	strob_strcpy(fp, "");
-	ls_list_safe_print_to_strob(name, fp);
+	ls_list_safe_print_to_strob(name, fp, vflag & LS_LIST_VERBOSE_PREPEND_DOTSLASH);
 	strob_strcat(fp, " " LS_LIST_LINKNAME_MARK);
 	print_linkname(fp, type, ln_name);
 	strob_strcat(fp, "]");
@@ -518,7 +541,7 @@ ls_list_to_string(char * fp_name, char * ln_name, struct new_cpio_header * file_
 	strob_strcat(fp, " ");
 
 	/* Print the name */
-	ls_list_safe_print_to_strob(name, fp);
+	ls_list_safe_print_to_strob(name, fp, vflag & LS_LIST_VERBOSE_PREPEND_DOTSLASH);
 
 	/* Print the linkname for symlinks and hard links */
 	print_linkname(fp, type, ln_name);
