@@ -48,6 +48,8 @@ typedef struct {
 	mode_t umask_;
 	int close_list_[10];
 	int (*f_exec_)(void * cmd);
+	int (*f_filter_)(int ofd, int ifd, void * ctrl);
+	void * f_filter_ctrl_;
 	int close_all_fd_;
 	int child_gone_;
 	int esrch_;
@@ -55,8 +57,8 @@ typedef struct {
 } SHCMD;
 
 #define SHCMD_TAINTED_CHARS	"'\"|*?;&<>`$"
-#define SHCMD_UNSET_EXITVAL 65536
-#define SHCMD_INTERNAL_CAT	""
+#define SHCMD_UNSET_EXITVAL 1000
+#define SHCMD_INTERNAL_FILTER	"/."  /* special never-used name, to mean run internal function */
 
 SHCMD* 		shcmd_open(void);
 void   		shcmd_close(SHCMD * shcmd);
