@@ -93,7 +93,7 @@ swlib_ptym_open(char *pts_name, int * start)
 	char ptr2char[]="0123456789abcdef";
 	char * ptr2start;
 
-	if (*start < 0 || *start >= strlen(ptr2char)) return -1;
+	if (*start < 0 || (unsigned int)(*start) >= strlen(ptr2char)) return -1;
 
 	ptr2start = ptr2char + (*start);
 
