@@ -68,5 +68,9 @@ int swgpg_disentangle_status_lines(SWGPG_VALIDATE * w, char * gpg_output_lines);
 void swgpg_set_passphrase_fd(int fd);
 int swgpg_get_passphrase_fd(void);
 void swgpg_init_passphrase_fd(void);
+char * swgpg_get_package_signature( SHCMD * sigcmd, int * statusp, char * wopt_passphrase_fd, char * passfile,
+		int pkg_fd, int do_dummy_sign, char * g_passphrase);
+SHCMD * swgpg_get_package_signature_command( char * signer, char * gpg_name, char * gpg_path,
+		char * passphrase_fd);
 
 #endif
