@@ -4,7 +4,7 @@
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -14,8 +14,12 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
+#define FILENEEDDEBUG 1
+#undef FILENEEDDEBUG
+
+#include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -31,16 +35,6 @@
 #include "fnmatch_u.h"
 
 #include "debug_config.h"
-#ifdef TARUIBNEEDDEBUG
-#define TARUIB_E_DEBUG(format) SWBISERROR("TARUIB DEBUG: ", format)
-#define TARUIB_E_DEBUG2(format, arg) SWBISERROR2("TARUIB DEBUG: ", format, arg)
-#define TARUIB_E_DEBUG3(format, arg, arg1) \
-				SWBISERROR3("TARUIB DEBUG: ", format, arg, arg1)
-#else
-#define TARUIB_E_DEBUG(arg)
-#define TARUIB_E_DEBUG2(arg, arg1)
-#define TARUIB_E_DEBUG3(arg, arg1, arg2)
-#endif 
 
 static int g_taruib_gst_overflow_releaseM;
 static int g_taruib_gst_fdM;
@@ -62,6 +56,11 @@ static char * sha1sum_pattern[3] = {
 	"*/catalog/*/sha1sum",
 	(char*)NULL };
 
+static char * sha512sum_pattern[3] = {
+	"catalog/*/sha512sum",
+	"*/catalog/*/sha512sum",
+	(char*)NULL };
+
 static char * signature_pattern[3] = {
 	"catalog/*/" SWBN_SIGNATURE,
 	"*/catalog/*/" SWBN_SIGNATURE,
@@ -76,7 +75,7 @@ static
 char **
 determine_pattern_array(int * detpat, char * name) {
 
-	TARUIB_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	if (strstr(name, "/md5sum")) {
 		*detpat = TARUIB_N_MD5;
 		return md5sum_full_pattern;
@@ -86,6 +85,9 @@ determine_pattern_array(int * detpat, char * name) {
 	} else if (strstr(name, "/sha1sum")) {
 		*detpat = TARUIB_N_SHA1;
 		return sha1sum_pattern;
+	} else if (strstr(name, "/sha512sum")) {
+		*detpat = TARUIB_N_SHA512;
+		return sha512sum_pattern;
 	} else if (
 		strstr(name, "/" SWBN_SIGNATURE) &&
 		strlen(strstr(name, "/" SWBN_SIGNATURE)) ==
@@ -111,7 +113,7 @@ int
 check_useArray(int * useArray, int digest_type, int dfd)
 {
 	int ret = -1;
-	TARUIB_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	if (useArray) {
 		if (digest_type > 4) return -1;
 		if (useArray[digest_type] && digest_type != TARUIB_N_SIG) {
@@ -143,7 +145,8 @@ verbose_decode(int * useArray, int * detpat,
 				int verbose,
 				int md5digestfd,
 				int sha1digestfd,
-				int sigfd)
+				int sigfd,
+				int sha512digestfd)
 {
 	int i = 0;
 	int ret;
@@ -152,7 +155,7 @@ verbose_decode(int * useArray, int * detpat,
 	char ** pattern_array;
 	STROB * tmp;
 
-	TARUIB_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	if (verbose == 0) return nullfd;
 
 	if (prepath && strlen(prepath)) {
@@ -188,6 +191,8 @@ verbose_decode(int * useArray, int * detpat,
 			pattern_array = md5sum_full_pattern;
 		} else if(digest_type == TARUIB_N_SHA1) {
 			pattern_array = sha1sum_pattern;
+		} else if(digest_type == TARUIB_N_SHA512) {
+			pattern_array = sha512sum_pattern;
 		} else if(digest_type == TARUIB_N_SIG_HDR) {
 			pattern_array = signature_header_pattern;
 		} else {
@@ -223,6 +228,10 @@ verbose_decode(int * useArray, int * detpat,
 				passfd = check_useArray(useArray,
 							digest_type,
 							sha1digestfd);
+			} else if (digest_type == TARUIB_N_SHA512 && sha512digestfd >= 0) {
+				passfd = check_useArray(useArray,
+							digest_type,
+							sha512digestfd);
 			} else if (digest_type == TARUIB_N_SIG_HDR) {
 				passfd = nullfd;
 			} else {
@@ -248,7 +257,7 @@ check_signature_name(char * sigfilename, char * prevname)
 	char * p;
 	char * s;
 
-	TARUIB_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	s = strstr(sigfilename, "/" SWBN_SIGNATURE);
 	if (!s || *(s + strlen("/" SWBN_SIGNATURE)) != '\0' ) {
 		return 1;
@@ -264,102 +273,6 @@ check_signature_name(char * sigfilename, char * prevname)
 	return ret;
 }
 
-static
-int
-do_sig_safety_checks(int memfd, int sigsize, int whichsig)
-{
-	/*
-	* the signature data can only contain a leading printable block
-	* of chars followed by a contigous block of nulls.
-	*/
-	char * data;
-	int data_len;
-	int cnt = 0;
-	char * s;	
-	int foundnull = 0;
-	int foundchar = 0;
-	int which_offset = 0;
-	int nsig;
-
-	if (uxfio_get_dynamic_buffer(memfd, &data, NULL, &data_len) < 0) {
-		return -1;
-	}
-
-	if (whichsig == 0) {
-		/*
-		* sanity check
-		*/
-		if (data_len < sigsize) {
-			return -3;
-		}
-	}
-
-	if (whichsig > 0) {
-		/*
-		* sanity check
-		*/
-		if (data_len < (whichsig * sigsize)) {
-			return -4;
-		}
-	}
-
-	if (data_len % sigsize) {
-		/*
-		* sanity check
-		*/
-		return -5;
-	}
-
-	nsig = data_len / sigsize;
-
-	if (nsig < 1) {
-		/*
-		* sanity check
-		*/
-		return -6;
-	}
-
-	if (whichsig == 0) {
-		which_offset = (nsig-1) * sigsize;
-	} else if (whichsig > 0) {
-		which_offset = (whichsig-1) * sigsize;
-	} else {
-		return -7;
-	}
-
-	s = data + which_offset;
-	while (cnt < sigsize) {
-		switch ((int)(*s)) {
-			case '\0':
-				if (!foundchar) {
-					fprintf(stderr,
-						"Corrupt char in sigfile\n");
-					return 3;
-				}
-				foundnull++;
-				break;
-
-			default:
-				if (foundnull) {
-					fprintf(stderr,
-						"Corrupt char in sigfile\n");
-					return 2;
-				}
-				if ( !isprint((int)(*s)) && 
-						*s != '\x0a' && *s != '\x0d') {
-					fprintf(stderr, 
-						"Corrupt char in sigfile\n");
-					return 1;
-				}
-				foundchar++;
-				break;
-		}
-		s++;
-		cnt++;
-	}
-	return 0;
-}
-
 static
 int
 do_header_safety_checks(XFORMAT * package,
@@ -375,7 +288,7 @@ do_header_safety_checks(XFORMAT * package,
 	char * header_bytes;
 	int ret = 0;
 	
-	TARUIB_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	if (check_signature_name(name, prevname)) {
 		fprintf(stderr, 
 		"Warning: *** The file name [%s]\n"
@@ -469,7 +382,7 @@ taruib_write_pass_files(void * vp, int ofd, int adjunct_ofd_p)
 	int retval = 0;
 	int total_sym_bytes = 0;
 
-	TARUIB_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	adjunct_ofd  = adjunct_ofd_p;
 	if (adjunct_ofd < 0) adjunct_ofd = -1;
 	taruib_set_overflow_release(0);
@@ -643,24 +556,29 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 	SWPATH * swpath = swpath_open("");
 	TARU * taru = taru_create();
 
-	TARUIB_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	nullfd = open("/dev/null", O_RDWR);
 	if (!swpath) return -21;
 	if (nullfd < 0) return -22;		
 	if (ifd < 0) return -32;		
 	if (!taru) return -20;
 
+	E_DEBUG("");
 	taruib_set_fd(ofd);
 	while ((ret = xformat_read_header(package)) > 0) {
+		E_DEBUG("");
 		retval += ret;
 		if (xformat_is_end_of_archive(package)){
 			/*
 			* This is probably a package with no storage files.
 			*/
+			/*  jhl 2006-09-08  warning eliminated
 			fprintf(stderr,
-		"taruib_write_catalog_stream: warning: end of archive.\n");
+			"taruib_write_catalog_stream: warning: end of archive.\n");
+			*/
 			break;
 		}
+		E_DEBUG("");
 		xformat_get_name(package, namebuf);
 		name = strob_str(namebuf);
 		path_ret = swpath_parse_path(swpath, name);
@@ -668,11 +586,12 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 			fprintf(stderr,
 		"taruib_write_catalog_stream: error parsing path [%s].\n",
 				name);
-			TARUIB_E_DEBUG("LEAVING");
+			E_DEBUG("LEAVING");
 			return -1;
 		}
 		prepath = swpath_get_prepath(swpath);
 
+		E_DEBUG("");
 		/*
 		* version 0: include the leading directories.
 		* version 1: exclude the leading directories.
@@ -687,6 +606,7 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 			 * Leading directories and the /catalog/ files.
 			 */
 
+			E_DEBUG("");
 			if ( strcmp(swpath_get_basename(swpath),
 							SWBN_SIGNATURE) == 0 &&
 			 	 strlen(swpath_get_dfiles(swpath)) &&
@@ -696,25 +616,28 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 				 * Its the signature file in the dfiles
 				 * directory,
 				 */
+				E_DEBUG("");
 				check_ret = do_header_safety_checks(package,
 							strob_str(namebuf),
 							strob_str(prevname),
 							NULL);
 				if (check_ret < 0) {
-					TARUIB_E_DEBUG("LEAVING");
+					E_DEBUG("LEAVING");
 					return -1;
 				}
 
+				E_DEBUG("");
 				got_sig = 1;
 				taruib_unread(ret);
 				retval -= ret;
 				taruib_set_overflow_release(0); /* OFF */
 				taruib_set_fd(-1);
 				
+				E_DEBUG("");
 				if (verbose && version == 1) {
 					passfd = verbose_decode(NULL, NULL,
 							prepath, name, nullfd,
-							2, verbose, -1, -1, -1);
+							2, verbose, -1, -1, -1, -1);
 				} else {
 					passfd = nullfd;
 				}
@@ -724,6 +647,7 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 				/*
 				* Copy it.
 				*/
+				E_DEBUG("");
 				taruib_set_overflow_release(0); /* OFF */
 
 				/*
@@ -734,23 +658,28 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 				* (and flushed) by the read routine in 
 				* xformat_copy_pass().
 				*/
+				E_DEBUG("");
+				E_DEBUG3("nullfd=%d  ifd=%d", nullfd, ifd);
 				copyret = xformat_copy_pass(package,
 							nullfd, ifd);
 				if (copyret < 0) {
+					E_DEBUG("");
 					swpath_close(swpath);
 					strob_close(namebuf);
 					strob_close(prevname);
-			TARUIB_E_DEBUG("LEAVING : xformat_copy_pass error.");
+					E_DEBUG("LEAVING : xformat_copy_pass error.");
 					fprintf(stderr,
 					"swbis : xformat_copy_pass() error\n");
 					return copyret;
 				}
 
+				E_DEBUG("");
 				if (copyret == 0) {
 					/*
 					* If there was nothing to write, then
 					* flush the buffer.
 					*/
+					E_DEBUG("");
 					if(taruib_clear_buffer() < 0) {
 						fprintf(stderr, 
 			"Internal error in taruib_write_catalog_stream : %d\n", 
@@ -760,14 +689,19 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 				} else {
 					retval += copyret;
 				}
+				E_DEBUG("");
 			}
+			E_DEBUG("");
 		} else {
+			E_DEBUG("");
 			if (version == 1) {
+				E_DEBUG("");
 				if (is_catalog == SWPATH_CTYPE_DIR) {
 					/*
 					* skip leading dirs.
 					* continue;
 					*/
+					E_DEBUG("");
 					taruib_unread(ret);	
 					retval -= ret;
 					taruib_set_overflow_release(0);/*OFF*/
@@ -778,13 +712,14 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 					/*
 					* into storage structure.  Stop
 					*/
+					E_DEBUG("");
 					taruib_unread(ret);	
 					retval -= ret;
 					break;
 				} else {
 					fprintf(stderr, 
 			"internal error : taruib_write_catalog_stream\n");
-					TARUIB_E_DEBUG("LEAVING");
+					E_DEBUG("LEAVING");
 					return -1;
 				}
 			} else if (version == 0) {  /* version == 0 */
@@ -793,15 +728,18 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 				* Assertion: is_catalog == 0.
 				*   Stop.
 				*/
+				E_DEBUG("");
 				taruib_unread(ret);	
 				retval -= ret;
 				break;
 			} else {
+				E_DEBUG("");
 				fprintf(stderr, "internal error \n");
-				TARUIB_E_DEBUG("LEAVING");
+				E_DEBUG("LEAVING");
 				return -1;
 			}
 		}
+		E_DEBUG("");
 		/*
 		* Prepare to read the next header
 		*/
@@ -810,7 +748,8 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 	}
 
 	if (ret >= 0) {
-		if(taruib_clear_buffer() < 0) {
+		E_DEBUG("");
+		if (taruib_clear_buffer() < 0) {
 			fprintf(stderr, 
 			"Internal error in taruib_write_catalog_stream : %d\n",
 				__LINE__);
@@ -818,10 +757,12 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 		}
 	}
 
+	E_DEBUG("");
 	if (version == 1) {
 		/*
 		* write two (null) trailer blocks if tar format.
 		*/
+		E_DEBUG("");
 		retval += taru_write_archive_trailer(taru, arf_ustar, 
 							ofd, TARRECORDSIZE, 0, 0);
 		if (got_sig == 0) {
@@ -830,9 +771,11 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 	}
 
 	close(nullfd);
+	E_DEBUG("");
 	strob_close(namebuf);
+	E_DEBUG("");
 	swpath_close(swpath);
-	TARUIB_E_DEBUG2("LEAVING retval = %d", retval);
+	E_DEBUG2("LEAVING retval = %d", retval);
 	return  retval;
 }
 
@@ -874,7 +817,7 @@ taruib_write_storage_stream(void * vp, int ofd, int version, int ofd2,
 	*	signature 	2
 	*	sha1sum   	3
 	*/
-	TARUIB_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 
 	if (ofd2 > 0) {
 		do_adjunct = 1; 
@@ -894,7 +837,7 @@ taruib_write_storage_stream(void * vp, int ofd, int version, int ofd2,
 		header_bytes = ret;
 		retval += ret;
 		if (xformat_is_end_of_archive(package)){
-			fprintf(stderr, "taruib: empty payload section\n");
+			/* fprintf(stderr, "taruib: empty payload section\n"); */
 			retval = taru_write_archive_trailer(taru, arf_ustar,
 							ofd, 512, 0, 0);
 			close(nullfd);
@@ -909,7 +852,7 @@ taruib_write_storage_stream(void * vp, int ofd, int version, int ofd2,
 			fprintf(stderr, 
 				"taruib_write_storage_stream:"
 					" error parsing path [%s].\n", name);
-			TARUIB_E_DEBUG("LEAVING");
+			E_DEBUG("LEAVING");
 			return -1;
 		}
 		prepath = swpath_get_prepath(swpath);
@@ -964,7 +907,7 @@ taruib_write_storage_stream(void * vp, int ofd, int version, int ofd2,
 				passfd = verbose_decode(NULL, NULL,
 							prepath, name,
 							nullfd, digest_type,
-							verbose, -1, -1, -1);
+							verbose, -1, -1, -1, -1);
 				copyret = xformat_copy_pass_file_data(package, 
 								passfd, ifd);
 				
@@ -1061,7 +1004,7 @@ taruib_arfcopy(void * xpackage,
 		int xofd, 
 		char * leadingpath, 
 		int do_preview, 
-		unsigned long int * statbytes, 
+		uintmax_t * statbytes, 
 		int * deadman,
 		void (*alarm_handler)(int))
 {
