@@ -13,7 +13,7 @@
 #include "swdefinitionfile.h"
 #include "swindex.h"
 
-#include "swparser_global.h"
+#include "swmain.h"
 
 int main (int argc, char ** argv) {
 	swDefinitionFile *swindex;
