@@ -33,7 +33,7 @@ echo $0: Using swign at `which swign`
 PASSPHRASE="willbe delivered by /runswpackagetest"
 AUTHOR="doesntwillbe overridden by /runswpackagetest"
 
-swign -u "$AUTHOR" @- | swverify --checksig
+swign -s . -u "$AUTHOR" @- | swverify -d @-
 ret=$?
 rm -fr /var/tmp/swbis-test-user$$ tmp/swpackage
 exit $ret
