@@ -30,7 +30,7 @@ echo $0: Using swign at `which swign`
 echo
 (
 	export SWPACKAGEPASSFD=3
-	exec 3<$PASSFILE swign  -u "$AUTHOR" -D bin/checksig-nosym.sh -S
+	exec 3<$PASSFILE swign -s .  -u "$AUTHOR" -D bin/checkdigest.sh -S
 )
 swverify --scm -d @.
 ret=$?
